@@ -28,36 +28,81 @@ class R_DST_Ridge(BaseEstimator, ClassifierMixin):
 
     Parameters
     ----------
+    transform_type : str, optional
+        Type of transformer to use. Based on the characteristics of the input
+        time series, different class of transformer must be used, for example
+        the tranformer for univariate series is not the same as for
+        multivariate ones for run-time optimization reasons.
+        The default is 'auto', which automatically select the transformer based
+        on the data passed in the fit method.
+    phase_invariance : bool, optional
+        Wheter to use phase invariance for shapelet sampling and distance 
+        computation. The default is False.
+    distance : str, optional
+        The distance function to use whe computing distances between shapelets
+        and time series. Choose between 'euclidean','manhattan' and 'squared_euclidean'.
+        The default is 'manhattan'.
+    alpha : float, optional
+        The alpha similarity parameter, the higher the value, the lower the 
+        allowed number of common indexes with previously sampled shapelets 
+        when sampling a new one with similar parameters. It can cause the
+        number of sampled shapelets to be lower than n_shapelets if the
+        whole search space has been covered. The default is 0.5.
+    normalize_output : boolean, optional
+        Wheter to normalize the argmin and shapelet occurrence feature by the 
+        length of the series from which it was extracted. This is mostly useful
+        for variable length time series. The default is False.
+    n_samples : float, optional
+        Proportion (in ]0,1]) of samples to consider for the shapelet
+        extraction. The default is None, meaning that all samples are used.
     n_shapelets : int, optional
-        Number of shapelets to generate. The default is 10000.
-    shapelet_sizes : array, optional
-        An array of int which indicate the possible absolute shapelet sizes.
-        Or an array of float which will give shapelet sizes relative to input length.
-        The default is [11]
-    p_norm : float, optional
-        A float between 0 and 1 indicating the proportion of shapelets that
-        will use a z-normalized distance. The default is 0.8.
-    percentiles : array, shape=(2), optional
-        The two percentiles (between 0 and 100) between which the value of the
-        threshold will be sampled during shapelet generation. 
-        The default is [5,10].
-    random_state : int, optional
-        Value of the random state for all random number generation.
-        The default is None.
+        The maximum number of shapelet to be sampled. The default is 10_000.
+    shapelet_lengths : array, optional
+        The set of possible length for shapelets. The values can be integers
+        to specify an absolute length, or a float, to specify a length relative 
+        to the input time series length. The default is [11].
+    shapelet_lengths_bounds : array, optional
+        An 1D array with two elements containing the min and max possible 
+        length for shapelet candidate, can be int or float. The default is
+        None, meaning that shapelet_lengths parameter is used.
+    lengths_bounds_reduction : float, optional
+        A float in ]0,1], quantifying the proportion of lengths to explore 
+        between the min and max bounds of shapelet_lengths_bounds. The default
+        is 0.5. For example, with bounds as [4,10], and a reduction of 0.5,
+        only [4,6,8,10] will be considered as possible lengths.
+    prime_dilations : bool, optional
+        If True, only dilation with prime values will be considered for 
+        shapelet candidates. This will greatly speed-up the algorithm
+        for long time series and/or short shapelet length, possibly at the cost
+        of some accuracy.
+    proba_norm : float, optional
+        The proportion of shapelets that will use a normalized distance 
+        function, which induce scale invariance. The default is 0.8.
+    percentiles : array, optional
+        The two perceniles used to select the lambda threshold used to compute
+        the Shapelet Occurrence feature. The default is [5,10].
     n_jobs : int, optional
-        Number of thread used by numba for the computational heavy part
-        of the algortihm. The default is 1. Change to -1 to use all
-        available cores.
+        The number of threads used to sample and compute the distance vectors.
+        The default is 1, -1 means all available cores.
+    random_state : object, optional
+        The seed for the random state. The default is None.
+    max_channels : int, optional
+        The maximum number of feature possibly considered by a multivariate 
+        shapelet. The default is None, meaning max_chanels=n_features.
+    min_len : int, optional
+        The minimum length of an input time series for variable length input.
+        The default is None, meaning min_len=min(n_timestamps) on the training data.
+        This can cause error if a shorter serie sis present in the test set.
     class_weight : object, optional
-        Class weight option of Ridge Classifier, either None, "balanced" or a
-        custom dictionnary of weight for each class. The default is None.
-    fit_intercept : bool, optional
-        If True, the intercept term will be fitted during the ridge regression.
-        The default is True.
-    alphas : array, optional
-        Array of alpha values to try which influence regularization strength, 
-        must be a positive float.
-        The default is np.logspace(-4,4,10).
+         Class weight option of Ridge Classifier, either None, "balanced" or a
+         custom dictionnary of weight for each class. The default is None.
+     fit_intercept : bool, optional
+         If True, the intercept term will be fitted during the ridge regression.
+         The default is True.
+     alphas : array, optional
+         Array of alpha values to try which influence regularization strength, 
+         must be a positive float.
+         The default is np.logspace(-4,4,20).
     """
     
     def __init__(
