@@ -17,7 +17,13 @@ from convst.transformers._commons import (
 
 from numba import njit, prange
 
-@njit(cache=True, nogil=True)
+from convst import (
+    __USE_NUMBA_CACHE__, __USE_NUMBA_FASTMATH__,
+    __USE_NUMBA_NOGIL__, __USE_NUMBA_PARALLEL__
+)
+
+
+@njit(cache=__USE_NUMBA_CACHE__, nogil=__USE_NUMBA_NOGIL__)
 def M_SL_init_random_shapelet_params(
     n_shapelets, shapelet_sizes, n_timestamps, p_norm, max_channels, prime_scheme
 ):
@@ -37,6 +43,9 @@ def M_SL_init_random_shapelet_params(
         shapelet to use z-normalized distance
     max_channels : int
         The maximum number of features considered for one shapelet
+    prime_scheme : bool
+        Wheter to only consider prime numbers as possible dilation 
+
         
     Returns
     -------
@@ -93,7 +102,7 @@ def M_SL_init_random_shapelet_params(
 
     return values, lengths, dilations, threshold, normalize, n_channels, channel_ids
 
-@njit(cache=True, parallel=True, nogil=True)
+@njit(cache=__USE_NUMBA_CACHE__, parallel=__USE_NUMBA_PARALLEL__, nogil=__USE_NUMBA_NOGIL__)
 def M_SL_generate_shapelet(
     X, y, n_shapelets, shapelet_sizes, r_seed, p_norm, p_min, p_max, alpha,
     dist_func, use_phase, max_channels, prime_scheme
@@ -127,6 +136,9 @@ def M_SL_generate_shapelet(
         input.
     use_phase: bool
         Wheter to use phase invariance
+    prime_scheme : bool
+        Wheter to only consider prime numbers as possible dilation 
+
     
     Returns
     -------
@@ -142,7 +154,7 @@ def M_SL_generate_shapelet(
         threshold : array, shape=(n_shapelets)
             Threshold parameter of the shapelets
         normalize : array, shape=(n_shapelets)
-            Normalization indicatorr of the shapelets
+            Normalization indicator of the shapelets
     """
     n_samples, n_features, n_timestamps = X.shape
     # Fix the random seed
@@ -267,7 +279,7 @@ def M_SL_generate_shapelet(
         channel_ids[:a2]
     )
 
-@njit(cache=True, parallel=True, fastmath=True, nogil=True)
+@njit(cache=__USE_NUMBA_CACHE__, parallel=__USE_NUMBA_PARALLEL__, fastmath=__USE_NUMBA_FASTMATH__, nogil=__USE_NUMBA_NOGIL__)
 def M_SL_apply_all_shapelets(
     X, shapelets, dist_func, use_phase
 ):
@@ -291,7 +303,7 @@ def M_SL_apply_all_shapelets(
         threshold : array, shape=(n_shapelets)
             Threshold parameter of the shapelets
         normalize : array, shape=(n_shapelets)
-            Normalization indicatorr of the shapelets
+            Normalization indicator of the shapelets
     dist_func: function
         A distance function implemented with Numba taking two 1D vectors as
         input.
