@@ -17,7 +17,13 @@ from convst.transformers._commons import (
 
 from numba import njit, prange
 
-@njit(cache=True, nogil=True)
+from convst import (
+    __USE_NUMBA_CACHE__, __USE_NUMBA_FASTMATH__,
+    __USE_NUMBA_NOGIL__, __USE_NUMBA_PARALLEL__
+)
+
+
+@njit(cache=__USE_NUMBA_CACHE__, nogil=__USE_NUMBA_NOGIL__)
 def M_VL_init_random_shapelet_params(
     n_shapelets, shapelet_sizes, n_timestamps, p_norm, max_channels, prime_scheme
 ):
@@ -37,6 +43,9 @@ def M_VL_init_random_shapelet_params(
         shapelet to use z-normalized distance
     max_channels : int
         The maximum number of features considered for one shapelet
+    prime_scheme : bool
+        Wheter to only consider prime numbers as possible dilation 
+
         
     Returns
     -------
@@ -93,7 +102,7 @@ def M_VL_init_random_shapelet_params(
 
     return values, lengths, dilations, threshold, normalize, n_channels, channel_ids
 
-@njit(cache=True, parallel=True, nogil=True)
+@njit(cache=__USE_NUMBA_CACHE__, parallel=__USE_NUMBA_PARALLEL__, nogil=__USE_NUMBA_NOGIL__)
 def M_VL_generate_shapelet(
     X, y, n_shapelets, shapelet_sizes, r_seed, p_norm, p_min, p_max, alpha,
     dist_func, use_phase, max_channels, min_len, X_len, prime_scheme
@@ -131,7 +140,9 @@ def M_VL_generate_shapelet(
         Minimum length for input time series
     X_len : array, shape=(n_samples)
         The length of each input time series
-    
+    prime_scheme : bool
+        Wheter to only consider prime numbers as possible dilation 
+
     Returns
     -------
     set of array, shape=(5)
@@ -297,7 +308,7 @@ def M_VL_generate_shapelet(
         channel_ids[:a2]
     )
 
-@njit(cache=True, parallel=True, fastmath=True, nogil=True)
+@njit(cache=__USE_NUMBA_CACHE__, parallel=__USE_NUMBA_PARALLEL__, fastmath=__USE_NUMBA_FASTMATH__, nogil=__USE_NUMBA_NOGIL__)
 def M_VL_apply_all_shapelets(
     X, shapelets, dist_func, use_phase, X_len
 ):
