@@ -16,7 +16,12 @@ from convst.transformers._commons import (
 
 from numba import njit, prange
 
-@njit(cache=True, nogil=True)
+from convst import (
+    __USE_NUMBA_CACHE__, __USE_NUMBA_FASTMATH__,
+    __USE_NUMBA_NOGIL__, __USE_NUMBA_PARALLEL__
+)
+
+@njit(cache=__USE_NUMBA_CACHE__, nogil=__USE_NUMBA_NOGIL__)
 def U_SL_init_random_shapelet_params(
     n_shapelets, shapelet_sizes, n_timestamps, p_norm, prime_scheme
 ):
@@ -34,6 +39,8 @@ def U_SL_init_random_shapelet_params(
     p_norm : float
         A value in the range [0,1] indicating the chance for each
         shapelet to use z-normalized distance
+    prime_scheme : bool
+        Wheter to only consider prime numbers as possible dilation 
 
     Returns
     -------
@@ -79,7 +86,7 @@ def U_SL_init_random_shapelet_params(
 
     return values, lengths, dilations, threshold, normalize
 
-@njit(cache=True, parallel=True, nogil=True)
+@njit(cache=__USE_NUMBA_CACHE__, parallel=__USE_NUMBA_PARALLEL__, nogil=__USE_NUMBA_NOGIL__)
 def U_SL_generate_shapelet(
     X, y, n_shapelets, shapelet_sizes, r_seed, p_norm, p_min, p_max, alpha,
     dist_func, use_phase, prime_scheme
@@ -98,7 +105,7 @@ def U_SL_generate_shapelet(
         Number of shapelet to generate
     shapelet_sizes : array, shape=()
         An array of possible shapelet length.
-    seed : int
+    r_seed : int
         Random seed generator for numpy
     p_norm : float
         Probability of each shapelet to use z-normalized distance
@@ -107,13 +114,16 @@ def U_SL_generate_shapelet(
     p_max : float
         Upper bound for the percentile during the choice of threshold
     alpha : float
-        Alpha similarity parameter
+        Alpha similarity parameter, higher values (close to 1) means higher
+        similarity prunning.
     dist_func: function
         A distance function implemented with Numba taking two 1D vectors as
         input.
     use_phase: bool
         Wheter to use phase invariance
-    
+    prime_scheme : bool
+        Wheter to only consider prime numbers as possible dilation 
+
     Returns
     -------
     set of array, shape=(5)
@@ -222,7 +232,7 @@ def U_SL_generate_shapelet(
     )
 
 
-@njit(cache=True, parallel=True, fastmath=True, nogil=True)
+@njit(cache=__USE_NUMBA_CACHE__, parallel=__USE_NUMBA_PARALLEL__, fastmath=__USE_NUMBA_FASTMATH__, nogil=__USE_NUMBA_NOGIL__)
 def U_SL_apply_all_shapelets(
     X, shapelets, dist_func, use_phase
 ):
